@@ -21,7 +21,7 @@ def run_collectstatic():
 
 
 @require_server
-def run_deploy_website():
+def run_deploy_website(restart_apache=False):
     """
     Executes all tasks necessary to deploy the website on the given server.
 
@@ -35,7 +35,10 @@ def run_deploy_website():
     run_rsync_project()
     run_syncdb()
     run_collectstatic()
-    run_restart_apache()
+    if restart_apache:
+        run_restart_apache()
+    else:
+        run_touch_wsgi()
 
 
 @require_server
@@ -197,6 +200,19 @@ def run_syncdb():
         run_workon('python2.7 manage.py syncdb --migrate --noinput')
 
 
+@require_server
+def run_touch_wsgi():
+    """
+    Runs `touch <path>/wsgi.py` on the given server.
+
+    Usage::
+
+        fab <server> run_touch_wsgi
+
+    """
+    run('touch {0}'.format(settings.SERVER_WSGI_FILE))
+
+
 @require_server
 def run_upload_db(filename=None):
     """
